<?php

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \Exception as Exception;

use \clearos\apps\base\File as File;
use \clearos\apps\base\Software as Software;

clearos_load_library('base/File');
clearos_load_library('base/Software');
///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

class App_1c extends ClearOS_Controller
{
    /**
     * Sites summary view.
     *
     * @return view
     */

    function index()
    {
        // Load libraries
        //---------------

	try {
    	    $this->load->library('server_1c/Server_1C');
    	    $this->lang->load('server_1c');        
	
	    $server_pkg = '1C_Enterprise83-common';
		
    	    $software_server = new Software($server_pkg);
        
    	    if ($software_server->is_installed()){
    	        $data['package_info']=$this->server_1c->get_info();
    		$this->page->view_form('app/applist', $data, lang('server_1c_app_name'));
    	    }else{    
    		$this->page->view_form('app/notinstalled', $data, lang('server_1c_app_name'));
    	    }
    	} catch (Exception $e) {
        	$this->page->set_message(clearos_exception_message($e));
    	}        
    }
    
    function configlog()
    {
	$this->load->library('Server_1C');
		
	$data = array();
	$data = $this->server_1c->get_config_section('logcfg');
	$this->page->view_form('app/configlog', $data, lang('server_1c_web_app_name'));
    }
    
    function config_log()
    {
	$this->load->library('Server_1C');
	
	$data['ALL']     = (int)$this->input->post('ALL');
	$data['ADMIN']   = (int)$this->input->post('ADMIN');
	$data['CALL']    = (int)$this->input->post('CALL');
        $data['CONN']    = (int)$this->input->post('CONN');
	$data['CLSTR']   = (int)$this->input->post('CLSTR');
	$data['EDS']     = (int)$this->input->post('EDS');
	$data['DB2']     = (int)$this->input->post('DB2');
	$data['DBMSSQL'] = (int)$this->input->post('DBMSSQL');
	$data['DBPOSTGRS'] = (int)$this->input->post('DBPOSTGRS');
	$data['DBORACLE']  = (int)$this->input->post('DBORACLE');
	$data['DBV8DBEng'] = (int)$this->input->post('DBV8DBEng');
	$data['EXCP']      = (int)$this->input->post('EXCP');
	$data['EXCPCNTX']  = (int)$this->input->post('EXCPCNTX');
	$data['HASP']      = (int)$this->input->post('HASP');
	$data['LEAKS']     = (int)$this->input->post('LEAKS');
	$data['MEM']       = (int)$this->input->post('MEM');
	$data['PROC']      = (int)$this->input->post('PROC');
	$data['QERR']      = (int)$this->input->post('QERR');
	$data['SCALL']     = (int)$this->input->post('SCALL');
	$data['SCOM']      = (int)$this->input->post('SCOM');
	$data['SDBL']      = (int)$this->input->post('SDBL');
	$data['SRVC']      = (int)$this->input->post('SRVC');
	$data['TLOCK']     = (int)$this->input->post('TLOCK');
	$data['TDEADLOCK'] = (int)$this->input->post('TDEADLOCK');
	$data['TTIMEOUT']  = (int)$this->input->post('TTIMEOUT');
	$data['VRSCACHE']  = (int)$this->input->post('VRSCACHE');
	$data['VRSREQUEST']  = (int)$this->input->post('VRSREQUEST');
	$data['VRSRESPONSE'] = (int)$this->input->post('VRSRESPONSE');
	$data['SYSTEM']      = (int)$this->input->post('SYSTEM');
	if(!($err = $this->server_1c->update_cfg_log($data))) {
		    redirect('/server_1c');
	    	    return;
	}
	
	$this->page->view_form('app/configlog', $data, lang('server_1c_app_settings'));
    }
    
    function itssubs()
    {
	$this->load->library('Server_1C');
	
	$data=$this->server_1c->get_config_section('ITS');
	$data['verify'] = $data['password'];
	$this->page->view_form('app/itssubs', $data, lang('server_1c_app_setting'));
    }
    
    function itssubs_add()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('username',   'server_1c/Server_1C', 'validate_username',   TRUE);
	$this->form_validation->set_policy('password',   'server_1c/Server_1C', 'validate_password',   TRUE);
	$this->form_validation->set_policy('verify',     'server_1c/Server_1C', 'validate_password', TRUE);

	$form_ok = $this->form_validation->run();
	

	try{
	    if ($this->input->post('password') != $this->input->post('verify')) {
                $form_ok = FALSE;
                $data['errs'][] = lang('base_password_and_verify_do_not_match');
    	    }
	    if($form_ok){
		$this->server_1c->its_subs_add( $this->input->post('username'),  $this->input->post('password'));	
		redirect('/server_1c');
		return;
	    }
	}catch(Exception $e){
	    $this->page->set_message('Platform Settings: '.clearos_exception_message($e));
	}
	
	$data['username'] = $this->input->post('username');
	$data['password'] = $this->input->post('password');
	$data['verify']   = $this->input->post('verify');
	$this->page->view_form('app/itssubs', $data, lang('server_1c_app_setting'));
$this->itssubs();
    }
    
    function rpmlist()
    {
	$this->load->library('Server_1C');
	

	$file = new File( CLEAROS_TEMP_DIR .'/platform_server_1c.lock');
	if($file->exists()){
	    redirect('/server_1c/app_1c/install1c/'.$file->get_contents());
	}else{
	    $rpmdata         = $this->server_1c->get_rpm_list();
	    if(!$rpmdata['exitcode']){
		$data['rpmlist'] = $rpmdata['items'];
	    }else{
		$data['errs'][]=$rpmdata['errmsg'];
	    }	    
	}
	$this->page->view_form('app/rpmlist', $data, lang('server_1c_app_setting'));
    }
    
    function install1c($platform)
    {
	$this->load->library('Server_1C');
	$file = new File( CLEAROS_TEMP_DIR .'/platform_server_1c.lock');
	if(!$file->exists()){
	    $data['platform']=$platform;
	    $this->server_1c->install_rpm($platform);
	}else{
	    $data['platform']=$file->get_contents();
	}
	$this->page->view_form('app/rpminstall', $data, lang('server_1c_app_setting'));
    }
    
    
    function progress()
    {
        clearos_profile(__METHOD__, __LINE__);

        // Load dependencies
        $this->load->library('Server_1C');

        header('Cache-Control: no-cache, must-revalidate');
        header('Content-type: application/json');
        try {
    		$fp = fopen( CLEAROS_TEMP_DIR .'/progress_server_1c.tmp', 'r' );
        	$progress=fgets( $fp );
        	fclose( $fp );
        	if(!empty($progress)) {

            	    echo json_encode(
                	Array(
                    	    'code' => '1', 'details' => 'Installation in progress',
                    	    'download' => $progress, 'install' => 0,
                    	    'errmsg' => ''
                	)
            	    );
            	    return;
        	}
        	echo json_encode(
            	    Array(
                	'code' => -999,
                	'errmsg' => lang('server_1c_no_data')
            	    )
        	);
        } catch (Exception $e) {
            echo json_encode(Array('code' => clearos_exception_code($e), 'errmsg' => clearos_exception_message($e)));
        }
    }
    
    function abortdownload()
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/app_1c/abort_download';
        $cancel_uri =  '/app/server_1c';
        $items = array(lang('server_1c_app_abort_download_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function abort_download()
    {
	$file = new File(CLEAROS_TEMP_DIR .'/1c.tar.gz',TRUE);
	if($file->exists())
	    $file->delete();
	$file = new File(CLEAROS_TEMP_DIR .'/platform_server_1c.lock',TRUE);
	if($file->exists())
	    $file->delete();
	$file = new File(CLEAROS_TEMP_DIR .'/progress_server_1c.tmp',TRUE);
	if($file->exists())
	    $file->delete();
	$this->rpmlist();
    }
    
    
    function install()
    {
	$this->load->library('Server_1C');
	$output =$this->server_1c->uninstall_platform();
	$data['log']=$output['output'];
	$output=$this->server_1c->install_platform();
	$data['log'].=$output['output'];
	$this->page->view_form('app/installlog', $data, lang('server_1c_app_name'));
	return;
	
    }
    
    function uninstall()
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/app_1c/uninstall_confirmed';
        $cancel_uri =  '/app/server_1c';
        $items = array(lang('server_1c_app_uninstall_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function uninstall_confirmed()
    {
	$this->load->library('Server_1C');
	$output=$this->server_1c->uninstall_platform();
	$data['log']=$output['output'];
	$this->page->view_form('app/installlog', $data, lang('server_1c_app_name'));
	return;
    }
    
    function uninstallpackage($package)
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/app_1c/uninstallpackage_confirmed/'.$package;
        $cancel_uri =  '/app/server_1c';
        $items = array($package);
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function uninstallpackage_confirmed($package)
    {
	$this->load->library('Server_1C');
	$output=$this->server_1c->uninstall_package($package);
	$data['log']=$output['output'];
	$this->page->view_form('app/installlog', $data, lang('server_1c_app_name'));
	return;
    }
}

