<?php

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \Exception as Exception;

use \clearos\apps\base\Software as Software;

clearos_load_library('base/Software');


///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

class Pg_1c extends ClearOS_Controller
{
    /**
     * Sites summary view.
     *
     * @return view
     */

    function index()
    {
        // Load libraries
        //---------------

	$data['errs'] = array();
        $this->load->library('server_1c/Postgres');
        $this->lang->load('server_1c');
        
        $software = new Software('postgresql96-server');
        
        if($software->is_installed()){
    	    if($this->postgres->get_pg_initdb_status()){
    		$data['running_state'] = $this->postgres->pg_status();
    		$output=$this->postgres->get_db_list();
    		if($output['exitcode']!=0){
    		    $data['errs'][]=$output['message'];
    		}
    		$data['databases']=$output['databases'];
    		$this->page->view_form('pg/pg_databases', $data, lang('server_1c_pg_name'));
    	    }else{
		$this->page->view_form('pg/pg_status', $data, lang('server_1c_pg_name'));
	    }
        }else{
    	    $this->page->view_form('pg/pg_notinstalled', $data, lang('server_1c_pg_name'));
        }
    }
    
    function pginstall()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$data['pg_installlog']=$this->postgres->pg_install();
	$this->page->view_form('pg/pg_installlog', $data, lang('server_1c_pg_name'));
	return;
    }
    
    function pginitdb()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$data['pg_installlog']=$this->postgres->pg_initdb();
	$this->page->view_form('pg/pg_installlog', $data, lang('server_1c_pg_name'));
	return;
    }
    
    function pgconnection()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	
	$connection=$this->postgres->get_config_section('PostgreSQL');
	
	if(isset($connection['host']))$data['host']=$connection['host']; else $data['host']='127.0.0.1';
	if(isset($connection['port']))$data['port']=$connection['port']; else $data['port']='5432';
	if(isset($connection['user']))$data['user']=$connection['user']; else $data['user']='postgres';
	if(isset($connection['password']))$data['password']=$connection['password']; else $data['password']='';
	if(isset($connection['password']))$data['verify']  =$connection['password'];  else $data['verify']='';
	
	$this->page->view_form('pg/pg_connectionedit', $data, lang('server_1c_pg_name'));
    }
    
    function pgconnection_edit()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	
	$this->form_validation->set_policy('user',     'server_1c/Postgres', 'validate_username',     TRUE);
	$this->form_validation->set_policy('host',     'server_1c/Postgres', 'validate_ip',           TRUE);
	$this->form_validation->set_policy('port',     'server_1c/Postgres', 'validate_port',         TRUE);
	$this->form_validation->set_policy('password', 'server_1c/Postgres', 'validate_password',     TRUE);
	$this->form_validation->set_policy('verify',   'server_1c/Postgres', 'validate_password',     TRUE);

	$form_ok = $this->form_validation->run();
	
	try{
	    if ($this->input->post('password') != $this->input->post('verify')) {
                $form_ok = FALSE;
                $data['errs'][] = lang('base_password_and_verify_do_not_match');
    	    }
	    if($form_ok){
		$this->postgres->connection_add( $this->input->post('host'), $this->input->post('port'), $this->input->post('user'),  $this->input->post('password'));	
		redirect('/server_1c');
		return;
	    }
	}catch(Exception $e){
	    $this->page->set_message('PostgreSQL Administrative Client: '.clearos_exception_message($e));
	}
	
	$data['host']     = $this->input->post('host');
	$data['port']     = $this->input->post('port');
	$data['user']     = $this->input->post('user');
	$data['password'] = $this->input->post('password');
	$data['verify']   = $this->input->post('verify');
	$this->page->view_form('pg/pg_connectionedit', $data, lang('server_1c_app_setting'));
    }
    
    function pgaccess()
    {	
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$data['access_list']=$this->postgres->get_access_list();
	$this->page->view_form('pg/pg_accesslist', $data, lang('server_1c_pg_name'));
	return;
    }
    
    function accessedit($url)
    {
	
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	
	$base64_string       = urldecode($url);
	$json_string         = base64_decode($base64_string);
	$params              = json_decode($json_string);
	
	$data['url']         = $url;
	$data['type']        = $params->TYPE;
	$data['database']    = $params->DATABASE;
	$data['user']        = $params->USER;
	$data['address']     = $params->ADDRESS;
	$data['method']      = $params->METHOD;
	$data['databases']   = array('all'=>'all');
	$database_list       = array_column($this->postgres->get_db_list()['databases'],'name');
        $data['databases']   = $data['databases']+ array_combine($database_list, $database_list);
	
	
	$this->page->view_form('pg/pg_accessedit', $data, lang('server_1c_pg_name'));
    }
    
    function access_edit()
    {   
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$this->load->library('network/Network_Utils');
	
	$this->form_validation->set_policy('user',    'server_1c/Postgres', 'validate_username',     TRUE);
	$this->form_validation->set_policy('address', 'server_1c/Postgres', 'validate_address',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$url                       = $this->input->post('url');
	$type                      = $this->input->post('type');
	$database                  = $this->input->post('database');
	$user                      = $this->input->post('user');
	$method                    = $this->input->post('method');
	$address                   = $this->input->post('address');
	$base64_string    = urldecode($url);
	$json_string      = base64_decode($base64_string);
	$params           = json_decode($json_string);
	
	try{
	    if($form_ok)
	    {
		$output=$this->postgres->update_access_list($params, $type, $database, $user, $method, $address);
	    	if($output['exitcode']==0){
		    redirect('/server_1c/pg_1c/pgaccess/');
		    return;
		}else{
		    $this->page->set_message('PostgreSQL Administrative Client: '.$output['message']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('PostgreSQL Administrative Client: '.clearos_exception_message($e));
	}
	
	$data['url']       = $url;
	$data['type']      = $type;
	$data['database']  = $database;
	$data['user']      = $user;
	$data['address']   = $address;
	$data['method']    = $method;
	$data['databases']   = array('all'=>'all');
	$database_list       = array_column($this->postgres->get_db_list()['databases'],'name');
        $data['databases']   = $data['databases']+ array_combine($database_list, $database_list);
	
	$this->page->view_form('pg/pg_accessedit', $data, lang('server_1c_pg_name'));
	
    }
    
    function stop()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$output=$this->postgres->pg_stop();
	if($output['exitcode']==0){
	    redirect('/server_1c');
	    return;
	}else{
	    $data['pg_installlog']=$this->postgres->$output['message'];
	    $this->page->view_form('pg/pg_installlog', $data, lang('server_1c_pg_name'));
	    return;
	}
    }
    
    function start()
    {	
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$output=$this->postgres->pg_start();
	if($output['exitcode']==0){
	    redirect('/server_1c');
	    return;
	}else{
	    $data['pg_installlog']=$this->postgres->$output['message'];
	    $this->page->view_form('pg/pg_installlog', $data, lang('server_1c_pg_name'));
	    return;
	}
    }
    
    function pgsetpassword()
    {	
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$this->page->view_form('pg/pg_setpassword', $data, lang('server_1c_pg_name'));
	return;
    }
    
    function pg_setpassword()
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	
	$this->form_validation->set_policy('password', 'server_1c/Postgres', 'validate_password',     TRUE);
	$this->form_validation->set_policy('verify',   'server_1c/Postgres', 'validate_password',     TRUE);

	$form_ok = $this->form_validation->run();
	
	try{
	    if ($this->input->post('password') != $this->input->post('verify')) {
                $form_ok = FALSE;
                $data['errs'][] = lang('base_password_and_verify_do_not_match');
    	    }
	    if($form_ok){
		$this->postgres->set_password($this->input->post('password'));	
		redirect('/server_1c');
		return;
	    }
	}catch(Exception $e){
	    $this->page->set_message('PostgreSQL Administrative Client: '.clearos_exception_message($e));
	}
	

	$data['password'] = $this->input->post('password');
	$data['verify']   = $this->input->post('verify');
	$this->page->view_form('pg/pg_setpassword', $data, lang('server_1c_app_setting'));
    }
    
    function pgbackup($dbname)
    {
	$this->lang->load('server_1c');
	$this->load->library('server_1c/Postgres');
	$output=$this->postgres->pg_backup($dbname);
	if($output['exitcode']==0){
	    redirect('/server_1c');
	    return;
	}else{
	    $data['pg_installlog']=$this->postgres->$output['message'];
	    $this->page->view_form('pg/pg_installlog', $data, lang('server_1c_pg_name'));
	    return;
	}
    }
}

