<?php

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \Exception as Exception;

use \clearos\apps\base\Daemon as Daemon;

clearos_load_library('base/Daemon');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Server 1C webapps controller.
 *
 * @category   apps
 * @package    server-1c
 * @subpackage controllers
 * @author     High Tech Lider ltd. <htlead@htlead.kz>
 * @copyright  2018 High Tech Lider
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://github.com/htlead/clear_os_1c_server
 */

class Rac_1c extends ClearOS_Controller
{
    /**
     * Sites summary view.
     *
     * @return view
     */

    function index()
    {
        // Load libraries
        //---------------

	$data['errs'] = array();
        $this->load->library('server_1c/Server_1C');
        $this->lang->load('server_1c');
        
	try {
	    $ras = new Daemon('ras');
	    $srv  = new Daemon('srv1cv83');
	    $data['running_state'] = $ras->get_running_state();
	    if(($srv->get_running_state())&&($ras->get_running_state())){
		$data['clusters']      = $this->server_1c->get_clusters_list();
	    }else{
		$data['clusters'] = array();
	    }
        } catch (Exception $e) {
            $data['errs'][]='Remote Administrative Client: '.clearos_exception_message($e);
        }	
	

	$this->page->view_form('rac/clusters', $data, lang('server_1c_app_name'));

    }
    
    function infobaseslist($cluster)
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data['infobases'] = $this->server_1c->get_infobases_list($cluster);	
	$data['cluster']   = $cluster;
	
	$this->page->view_form('rac/infobaseslist', $data, lang('server_1c_rac_app_name'));
    }
    
    function infobaseadd($cluster)
    {
	$this->load->library('server_1c/Server_1C');
	$this->load->library('base/Country');
	
	$data['LOCALE']          = $this -> country -> get_list();
	$data['locale']          = 'RU';
	$data['cluster']         = $cluster;
	$data['dbms']            = 'PostgreSQL';
	$data['sjd']             = 'off';
	$data['create_database'] = true;
	
	$this->page->view_form('rac/infobaseadd', $data, lang('server_1c_rac_app_name'));
    }
    
    function infobase_add()
    {
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('name',  'server_1c/Server_1C',     'validate_base',    TRUE);
	$this->form_validation->set_policy('db_server', 'server_1c/Server_1C', 'validate_server',   TRUE);
	$this->form_validation->set_policy('db_name',   'server_1c/Server_1C', 'validate_base',     TRUE);
	$this->form_validation->set_policy('db_user',   'server_1c/Server_1C', 'validate_base',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$cluster          =   $this->input->post('cluster');
	$name             =   $this->input->post('name');
	$dbms             =   $this->input->post('dbms');  
	$db_server        =   $this->input->post('db_server');
	$db_name          =   $this->input->post('db_name');
	$db_user          =   $this->input->post('db_user');   
	$db_pwd           =   $this->input->post('db_pwd');    
	$create_database  =   $this->input->post('create_database');   
	$locale           =   $this->input->post('locale');    
	$SJD              =   $this->input->post('scheduled_jobs_deny');
	try{
	    if($form_ok)
	    {
		$output=$this->server_1c->add_infobase($cluster, $name, $dbms, $db_server, $db_name, $db_user, $db_pwd, $create_database, $locale, $SJD);
		if($output['exitcode']==0){
		    redirect('/server_1c/rac_1c/infobaseslist/'.$cluster);
		    return;
		}else{
		    $this->page->set_message('Remote Administrative Client: '.$output['output']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('Remote Administrative Client: '.clearos_exception_message($e));
	}
	
	$this->infobaseadd($cluster);
    }
    
    function infobasedrop($cluster, $infobase)
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/rac_1c/infobase_drop/'.$cluster.'/'.$infobase;
        $cancel_uri =  '/app/server_1c/rac_1c/infobaseslist/'.$cluster;
        $items = array(lang('server_1c_rac_infobase_drop_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function infobase_drop($cluster, $infobase)
    {
	$this->load->library('server_1c/Server_1C');
	
	$this->server_1c->drop_infobase($cluster, $infobase);
	redirect('/server_1c/rac_1c/infobaseslist/'.$cluster);
    }
    
    function sessionslist($cluster, $infobase)
    {
	$this->load->library('server_1c/Server_1C');
	
	$data['sessions'] = $this->server_1c->get_sessions_list($cluster, $infobase);
	$data['cluster']  = $cluster;
	$data['infobase'] = $infobase;
	
	$this->page->view_form('rac/sessionslist', $data, lang('server_1c_rac_app_name'));
    }
    
    function terminatesession($cluster, $infobase, $session)
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/rac_1c/terminate_session/'.$cluster.'/'.$infobase.'/'.$session;
        $cancel_uri =  '/app/server_1c/rac_1c/sessionslist/'.$cluster.'/'.$infobase;
        $items = array(lang('server_1c_rac_session_drop_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    
    }
    
    function terminate_session($cluster,$infobase, $session)
    {
	$this->load->library('server_1c/Server_1C');
	
	$this->server_1c->terminate_session($cluster, $session);
	redirect('/server_1c/rac_1c/sessionslist/'.$cluster.'/'.$infobase);
    }
    
    function stop()
    {
	$ras = new Daemon('srv1cv83.ras');
	$ras -> set_running_state(false);
	redirect('/server_1c');
    }
    
    function start()
    {
	$ras = new Daemon('srv1cv83.ras');
	$ras -> set_running_state(true);
	redirect('/server_1c');
    }
    
    function clusteradd()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data = array();
	
	$data['expiration_timeout']= 0;
	$data['lifetime_limit']= 0;
	$data['max_memory_size']= 0;
	$data['max_memory_time_limit']= 0;
	$data['security_level']= 0;
	$data['session_fault_tolerance_level']= 0;
	$data['load_balancing_mode']= 'performance';
	$data['errors_count_threshold']= 0;
	$data['kill_problem_processes']= 0;
		
	$this->page->view_form('rac/clusteradd', $data, lang('server_1c_rac_app_name'));
    }
    
    
    function cluster_add()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('host',   'server_1c/Server_1C', 'validate_server',   TRUE);
	$this->form_validation->set_policy('port',   'server_1c/Server_1C', 'validate_port',     TRUE);
	$this->form_validation->set_policy('expiration_timeout',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('lifetime_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('max_memory_size',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('max_memory_time_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('security_level',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('session_fault_tolerance_level',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('errors_count_threshold',   'server_1c/Server_1C', 'validate_number',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$host                      = $this->input->post('host');
	$port                      = $this->input->post('port');
	$name                      = $this->input->post('name');
	$expiration_timeout        = $this->input->post('expiration_timeout');
	$lifetime_limit            = $this->input->post('lifetime_limit');
	$max_memory_size           = $this->input->post('max_memory_size');
	$max_memory_time_limit     = $this->input->post('max_memory_time_limit');
	$security_level            = $this->input->post('security_level');
	$session_fault_tolerance_level = $this->input->post('session_fault_tolerance_level');
	$load_balancing_mode       = $this->input->post('load_balancing_mode');
	$errors_count_threshold    = $this->input->post('errors_count_threshold');
	$kill_problem_processes    = $this->input->post('kill_problem_processes');

	try{
	    if($form_ok)
	    {
		$output=$this->server_1c->add_cluster($host, $port, $name, $expiration_timeout, $lifetime_limit, $max_memory_size, $max_memory_time_limit, $security_level, 
		                                          $session_fault_tolerance_level,$load_balancing_mode, $errors_count_threshold, $kill_problem_processes);	
	    	if($output['exitcode']==0){
		    redirect('/server_1c');
		    return;
		}else{
		    $this->page->set_message('Remote Administrative Client: '.$output['output']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('Remote Administrative Client: '.clearos_exception_message($e));
	}
	
	$this->clusteradd();
    }
    
    function clusteredit($cluster)
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data['cluster_info']= $this->server_1c->get_cluster_info($cluster);	
		
	$this->page->view_form('rac/clusteredit', $data, lang('server_1c_rac_app_name'));
    }
    
    
    function cluster_edit()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('expiration_timeout',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('lifetime_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('max_memory_size',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('max_memory_time_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('security_level',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('session_fault_tolerance_level',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('errors_count_threshold',   'server_1c/Server_1C', 'validate_number',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$data['cluster']           = $this->input->post('cluster');
	$cluster                   = $this->input->post('cluster');
	$name                      = $this->input->post('name');
	$expiration_timeout        = $this->input->post('expiration_timeout');
	$lifetime_limit            = $this->input->post('lifetime_limit');
	$max_memory_size           = $this->input->post('max_memory_size');
	$max_memory_time_limit     = $this->input->post('max_memory_time_limit');
	$security_level            = $this->input->post('security_level');
	$session_fault_tolerance_level = $this->input->post('session_fault_tolerance_level');
	$load_balancing_mode       = $this->input->post('load_balancing_mode');
	$errors_count_threshold    = $this->input->post('errors_count_threshold');
	$kill_problem_processes    = $this->input->post('kill_problem_processes');

	try{
	    if($form_ok)
	    {
		$output=$this->server_1c->update_cluster($cluster, $name, $expiration_timeout, $lifetime_limit, $max_memory_size, $max_memory_time_limit, $security_level, 
		                                          $session_fault_tolerance_level,$load_balancing_mode, $errors_count_threshold, $kill_problem_processes);	
	    	if($output['exitcode']==0){
		    redirect('/server_1c');
		    return;
		}else{
		    $this->page->set_message('Remote Administrative Client: '.$output['output']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('Remote Administrative Client: '.clearos_exception_message($e));
	}
	
	$this->clusteredit($cluster);
    }
    
    function clusterdrop($cluster)
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/rac_1c/cluster_drop/'.$cluster;
        $cancel_uri =  '/app/server_1c/rac_1c/servers/';
        $items = array(lang('server_1c_rac_cluster_drop_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function cluster_drop($cluster)
    {
	$this->load->library('server_1c/Server_1C');
	
	$this->server_1c->drop_cluster($cluster, $server);
	redirect('/server_1c');
    }
    
    function serverslist($cluster)
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data['servers']= $this->server_1c->get_servers_list($cluster);	
	$data['cluster']= $cluster;
		
	$this->page->view_form('rac/servers', $data, lang('server_1c_rac_app_name'));
    }
    
    function serveradd($cluster)
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data['cluster']= $cluster;
	$data['agent_port']='1540';
	$data['port_range']='1560:1591';
	$data['using']     ='normal';
	$data['infobases_limit']   = 8;
	$data['memory_limit']      = 0;
	$data['connections_limit'] = 128;
	$data['cluster_port']      = '1541';
	$data['dedicate_managers'] = 'none';
	$data['sw_processes_memory_limit'] = 0;
	$data['safe_call_memory_limit'] = 0;
	$this->page->view_form('rac/serveradd', $data, lang('server_1c_rac_app_name'));
    }
    
    
    function server_add()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('name',         'server_1c/Server_1C', 'validate_base',    TRUE);
	$this->form_validation->set_policy('agent_host',   'server_1c/Server_1C', 'validate_server',   TRUE);
	$this->form_validation->set_policy('agent_port',   'server_1c/Server_1C', 'validate_port',     TRUE);
	$this->form_validation->set_policy('infobases_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('connections_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('cluster_port',   'server_1c/Server_1C', 'validate_port',     TRUE);
	$this->form_validation->set_policy('sw_processes_memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('safe_call_memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('port_range',   'server_1c/Server_1C', 'validate_port_range',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$data['cluster']           = $this->input->post('cluster');
	$cluster                   = $this->input->post('cluster');
	$agent_host                = $this->input->post('agent_host');
	$agent_port                = $this->input->post('agent_port');
	$name                      = $this->input->post('name');
	$port_range                = $this->input->post('port_range');
	$using                     = $this->input->post('using');
	$infobases_limit           = $this->input->post('infobases_limit');
	$memory_limit              = $this->input->post('memory_limit');
	$connections_limit         = $this->input->post('connections_limit');
	$cluster_port              = $this->input->post('cluster_port');
	$dedicate_managers         = $this->input->post('dedicate_managers');
	$sw_processes_memory_limit = $this->input->post('sw_processes_memory_limit');
	$safe_call_memory_limit    = $this->input->post('safe_call_memory_limit');
	
	try{
	    if($form_ok)
	    {
		$output=$this->server_1c->add_server($cluster,$agent_host, $agent_port, $port_range, $name, $using, $infobases_limit, $memory_limit, $connections_limit, $cluster_port, 
			$dedicate_managers, $sw_processes_memory_limit, $safe_call_memory_limit);	
	    	if($output['exitcode']==0){
		    redirect('/server_1c/rac_1c/serverslist/'.$cluster);
		    return;
		}else{
		    $this->page->set_message('Remote Administrative Client: '.$output['output']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('Remote Administrative Client: '.clearos_exception_message($e));
	}
	
	$this->serveradd($cluster);
    }
    
    function serveredit($cluster, $server)
    {    
	$this->load->library('server_1c/Server_1C');
	
	$data['servers']= $this->server_1c->get_server_info($cluster, $server);	
	$data['cluster']= $cluster;
	$data['server'] = $server;
	$this->page->view_form('rac/serveredit', $data, lang('server_1c_rac_app_name'));
    }
    
    
    function server_edit()
    {    
	$this->load->library('server_1c/Server_1C');
	
	$this->form_validation->set_policy('infobases_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('connections_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('sw_processes_memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('safe_call_memory_limit',   'server_1c/Server_1C', 'validate_number',     TRUE);
	$this->form_validation->set_policy('port_range',   'server_1c/Server_1C', 'validate_port_range',     TRUE);
	
	$form_ok = $this->form_validation->run();
	
	$data['cluster']           = $this->input->post('cluster');
	$cluster                   = $this->input->post('cluster');
	$server                    = $this->input->post('server');
	$agent_host                = $this->input->post('agent_host');
	$agent_port                = $this->input->post('agent_port');
	$name                      = $this->input->post('name');
	$port_range                = $this->input->post('port_range');
	$using                     = $this->input->post('using');
	$infobases_limit           = $this->input->post('infobases_limit');
	$memory_limit              = $this->input->post('memory_limit');
	$connections_limit         = $this->input->post('connections_limit');
	$cluster_port              = $this->input->post('cluster_port');
	$dedicate_managers         = $this->input->post('dedicate_managers');
	$sw_processes_memory_limit = $this->input->post('sw_processes_memory_limit');
	$safe_call_memory_limit    = $this->input->post('safe_call_memory_limit');
	
	try{
	    if($form_ok)
	    {
		$output=$this->server_1c->update_server($cluster, $server ,$port_range, $using, $infobases_limit, $memory_limit, $connections_limit,
			$dedicate_managers, $sw_processes_memory_limit, $safe_call_memory_limit);	
	    	if($output['exitcode']==0){
		    redirect('/server_1c/rac_1c/serverslist/'.$cluster);
		    return;
		}else{
		    $this->page->set_message('Remote Administrative Client: '.$output['output']);
		}
		
	    }
	}catch(Exception $e){
	    $this->page->set_message('Remote Administrative Client: '.clearos_exception_message($e));
	}
	
	$this->serveredit($cluster, $server);
    }
    
    function serverdrop($cluster, $server)
    {
	$this->load->library('server_1c/Server_1C');

        $confirm_uri = '/app/server_1c/rac_1c/server_drop/'.$cluster.'/'.$server;
        $cancel_uri =  '/app/server_1c/rac_1c/serverslist/'.$cluster;
        $items = array(lang('server_1c_rac_server_drop_confirm'));
    
        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }
    
    function server_drop($cluster, $server)
    {
	$this->load->library('server_1c/Server_1C');
	
	$this->server_1c->drop_server($cluster, $server);
	redirect('/server_1c/rac_1c/serverslist/'.$cluster);
    }
    

}
